==> huaweicloudsdkcoc-3.1.140-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_interrupt_records_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInterruptRecordsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'interrupt_record_list': 'list[InterruptRecord]'
    }

    attribute_map = {
        'total': 'total',
        'interrupt_record_list': 'interrupt_record_list'
    }

    def __init__(self, total=None, interrupt_record_list=None):
        """ListInterruptRecordsResponse

        The model defined in huaweicloud sdk

        :param total: 总数
        :type total: int
        :param interrupt_record_list: 列表信息
        :type interrupt_record_list: list[:class:`huaweicloudsdkcoc.v1.InterruptRecord`]
        """
        
        super(ListInterruptRecordsResponse, self).__init__()

        self._total = None
        self._interrupt_record_list = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if interrupt_record_list is not None:
            self.interrupt_record_list = interrupt_record_list

    @property
    def total(self):
        """Gets the total of this ListInterruptRecordsResponse.

        总数

        :return: The total of this ListInterruptRecordsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListInterruptRecordsResponse.

        总数

        :param total: The total of this ListInterruptRecordsResponse.
        :type total: int
        """
        self._total = total

    @property
    def interrupt_record_list(self):
        """Gets the interrupt_record_list of this ListInterruptRecordsResponse.

        列表信息

        :return: The interrupt_record_list of this ListInterruptRecordsResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.InterruptRecord`]
        """
        return self._interrupt_record_list

    @interrupt_record_list.setter
    def interrupt_record_list(self, interrupt_record_list):
        """Sets the interrupt_record_list of this ListInterruptRecordsResponse.

        列表信息

        :param interrupt_record_list: The interrupt_record_list of this ListInterruptRecordsResponse.
        :type interrupt_record_list: list[:class:`huaweicloudsdkcoc.v1.InterruptRecord`]
        """
        self._interrupt_record_list = interrupt_record_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInterruptRecordsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.144-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_interrupt_records_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInterruptRecordsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'interrupt_record_list': 'list[InterruptRecord]'
    }

    attribute_map = {
        'total': 'total',
        'interrupt_record_list': 'interrupt_record_list'
    }

    def __init__(self, total=None, interrupt_record_list=None):
        r"""ListInterruptRecordsResponse

        The model defined in huaweicloud sdk

        :param total: 总数
        :type total: int
        :param interrupt_record_list: 列表信息
        :type interrupt_record_list: list[:class:`huaweicloudsdkcoc.v1.InterruptRecord`]
        """
        
        super(ListInterruptRecordsResponse, self).__init__()

        self._total = None
        self._interrupt_record_list = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if interrupt_record_list is not None:
            self.interrupt_record_list = interrupt_record_list

    @property
    def total(self):
        r"""Gets the total of this ListInterruptRecordsResponse.

        总数

        :return: The total of this ListInterruptRecordsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListInterruptRecordsResponse.

        总数

        :param total: The total of this ListInterruptRecordsResponse.
        :type total: int
        """
        self._total = total

    @property
    def interrupt_record_list(self):
        r"""Gets the interrupt_record_list of this ListInterruptRecordsResponse.

        列表信息

        :return: The interrupt_record_list of this ListInterruptRecordsResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.InterruptRecord`]
        """
        return self._interrupt_record_list

    @interrupt_record_list.setter
    def interrupt_record_list(self, interrupt_record_list):
        r"""Sets the interrupt_record_list of this ListInterruptRecordsResponse.

        列表信息

        :param interrupt_record_list: The interrupt_record_list of this ListInterruptRecordsResponse.
        :type interrupt_record_list: list[:class:`huaweicloudsdkcoc.v1.InterruptRecord`]
        """
        self._interrupt_record_list = interrupt_record_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInterruptRecordsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
